extensions [ gis ]   ; activates the gis extension

globals [
  max-sheep  ; don't let the sheep population grow too large
  land-patches  ; keeps track of the patches that are on land
]

; Sheep and wolves are both breeds of turtles
breed [ sheep a-sheep ]  ; sheep is its own plural, so we use "a-sheep" as the singular
breed [ wolves wolf ]
breed [ humans human ]   ; add humans as a breed (plural first, then singular)

turtles-own [ energy ]    ; both wolves and sheep have energy
wolves-own [ domesticated? ]   ; To know if the wolf is domesticated

patches-own [
  countdown   ; used to trigger grass regrowth
  land?  ; boolean that identifies is a cell is land
  wall?  ; boolean that identifies if the cell overlaps the wall (and thus is part of the wall)
  house   ; identifies which house owns the cell
  house-color  ; to show the extent of each house's territory
]

to setup
  clear-all

  setup-world   ; call the setup-world procedure to import GIS data
  setup-wall   ; call the setup-wall procedure to import the Wall vector
  setup-houses   ; call the setup-houses procedure to identify the kingdom in which each patch falls

  set land-patches patches with [ land? = true ]  ; Creates a patchset that comprises only land patches

  ask land-patches [   ; ask only land patches to do what's between the square brackets
    set pcolor one-of [ green brown ]   ; each patch chooses a color between the two
    ifelse pcolor = green   ; if they chose green...
      [ set countdown grass-regrowth-time ]   ; they need to set their countdown for when they'll get eaten
      [ set countdown random grass-regrowth-time ]   ; initialize grass regrowth clocks randomly for brown patches
  ]

  ask n-of initial-number-sheep land-patches [ ; asks n (n from the slider) patches to prout one sheep.
    sprout-sheep 1 [
      set shape "sheep"
      set color white
      set size 1.5  ; easier to see
      set label-color blue - 2
      set energy random (2 * sheep-gain-from-food)
    ]
  ]

  ask n-of initial-number-wolves land-patches [ ; asks n (n from the slider) patches to sprout one wolf.
    sprout-wolves 1 [
      set shape "wolf"
      set color black
      set size 2  ; easier to see
      set energy random (2 * wolf-gain-from-food)
      set domesticated? false    ; by default, wolves are wild
    ]
  ]

  add-humans   ; call the add-humans procedure

  display-labels
  reset-ticks
end

;;; OBSERVER PROCEDURE ;;;

to setup-world
  ; Set up a virtual world using GIS raster base maps
  let basemap gis:load-dataset "Land_raster.asc"  ; Loads the GIS data to temp variable basemap
  let world-wd gis:width-of basemap  ; Identifies the width of the GIS raster
  let world-ht gis:height-of basemap  ; Identifies the height of the GIS raster
  resize-world 0 ( world-wd - 1 ) 0 ( world-ht - 1 )  ; Sets the dimensions of the World window to fit the GIS raster
  gis:set-world-envelope gis:envelope-of basemap  ; Transforms the World window based on the GIS raster
  gis:set-sampling-method basemap "NEAREST_NEIGHBOR" ; makes sure resampling is by nearest neighbor

  ask patches [
    let myX pxcor  ; temp variable to record the X coordinate
    let myY pycor  ; temp variable to record the Y coordinate
    let myCoor ( list myX myY )  ; xy coordinates as a list for the next line
    set house-color gis:raster-sample basemap myCoor  ; Each patch querries the value from the raster at its location
  ]
  ; Identify land patches (house-color >= 0) (water patches have house-color -9999 in the raster)
  ask patches [
    ifelse house-color >= 0 [
      set land? true  ; patches with house-color >= 0 are land
    ][  ; closing the if statement
      set land? false  ; patches that have house-color < 0 (-9999 in this case) are water
      set pcolor blue   ; thus they are blue
    ]  ; closing the else statement
  ]  ; closing the "ask patches" statement

end

to setup-wall   ; observer procedure
  ; load the vector dataset of the wall into the temporary variable wall-basemal
  let wall-basemap gis:load-dataset "Wall.shp"
  ; ask patches that intersect with the wall line to set their wall? variable to true
  ask patches gis:intersecting wall-basemap [
    set land? false   ; Wall patches should not be walked on. This excludes them from the land-patches set
    set wall? true   ; to keep track of which patches are part of the wall
    set pcolor white   ; The wall is white as it is made of ice
  ]

end

to setup-houses   ; observer procedure
  ; load the vector dataset of houses  to the temporary houses-basemap variable
  let houses-basemap gis:load-dataset "W_political_revised.shp"
  ; set the min and max threshold for patches to decide if they are part of the polygon or not
  ; to be a part, a patch has to be covered at least 50% by a polygon
  gis:set-coverage-minimum-threshold 0.5
  gis:set-coverage-maximum-threshold 1
  ; ask patches to set their house variable based on the claimbedBy variable of the polygon they fall on
  gis:apply-coverage houses-basemap "CLAIMEDBY" house
  ; some cleaning necessary as the polygons do not fit perfectly with the raster
  let list-houses remove-duplicates ([ house ] of patches with [ land? = true ])
  set list-houses remove "no one" list-houses   ; removes the name associated with water
  ask patches [
    if land? = false and member? house list-houses   ; houses that fall within a polygon but are water...
    [ set house "no one" ]   ; ... change their house to "no one" (water)
  ]

end

to go
  ; stop the model if there are no wolves and no sheep
  if not any? turtles [ stop ]

  ask sheep [
    move
    ; in this version, sheep eat grass, grass grows, and it costs sheep energy to move
    set energy energy - 1   ; deduct energy for sheep only if running sheep-wolves-grass model version
    eat-grass    ; sheep eat grass only if running the sheep-wolves-grass model version
    death    ; sheep die from starvation only if running the sheep-wolves-grass model version
    reproduce sheep-reproduce   ; sheep reproduce at a random rate governed by a slider
  ]

  ask wolves [
    move   ; calls the move procedure
    set energy energy - 1   ; wolves lose energy as they move
    ifelse not domesticated? [   ; if the wolves are still wild... (same as saying "if domesticated? = FALSE")
      eat-sheep   ; ...they eat a sheep on their patch (only if they are still wild)
    ][   ; if the wolves are domesticates
      if energy < 20 [  ; ...and only if they are starving...
        eat-sheep   ; ... then they eat a sheep if there is one around
      ]   ; end of the "if energy < 20" bracket
    ]   ; end of the "else" bracket (if domesticated)
    eat-sheep   ; wolves eat a sheep on their patch (calls the eat-sheep procedure)
    death   ; wolves die if they run out of energy (calls the death procedure)
    reproduce wolf-reproduce   ; wolves reproduce at a random rate governed by a slider
  ]

  ask humans [    ; human actions, almost all the same as sheep and wolves
    move     ; calls the "move" procedure
    set energy energy - 1     ; humans also lose energy as they move
    humans-eat    ; Humans eat some of the sheep that are on their patch or the grass if available
    domesticate-wolves    ; Humans domesticate some of the wolves they encounter
    humans-feed-animals    ; humans feed their domesticated wolves
    death    ; humans die when they run out of energy
    reproduce humans-reproduce    ; wolves reproduce at a random rate governed by a slider
  ]

  ask patches [ grow-grass ]

  tick
  display-labels   ; calls the display-labels procedure
end

to move  ; turtle procedure
  rt random 50   ; turn right by a randon angle up to 50
  lt random 50   ; turn left by a random angle up to 50

  ifelse patch-ahead 1 != nobody [   ; checks if the patch in front of the agent is something (to turn at the edges)
    ifelse [ land? ] of patch-ahead 1 = true   ; if the patch in front of the agent is land
    [ fd 1 ]   ; if it is land, the agent move one step ahead
    [ rt 180 ]   ; if the patch is water, the agent turns 180 degrees
  ][ rt 180 ]   ; if the patch is nothing (edge), the agent turns 180 degrees

  fd 1
end

to eat-grass  ; sheep procedure
  ; sheep eat grass and turn the patch brown
  if pcolor = green [
    set pcolor brown
    set energy energy + sheep-gain-from-food  ; sheep gain energy by eating
  ]
end

to eat-sheep  ; wolf procedure
  let prey one-of sheep-here                    ; grab a random sheep
  if prey != nobody  [                          ; did we get one? if so,
    ask prey [ die ]                            ; kill it, and...
    set energy energy + wolf-gain-from-food     ; get energy from eating
  ]
end

to death  ; turtle procedure (i.e. both wolf and sheep procedure)
  ; when energy dips below zero, die
  if energy < 0 [ die ]
end

to grow-grass  ; patch procedure
  ; countdown on brown patches: if you reach 0, grow some grass
  if pcolor = brown [
    ifelse countdown <= 0
      [ set pcolor green
        set countdown grass-regrowth-time ]
      [ set countdown countdown - 1 ]
  ]
end

to-report grass
    report patches with [ pcolor = green ]    ; reports the number of green patches
end


to display-labels
  ask turtles [ set label "" ]   ; set labels to blank
  if show-energy? [   ; if show-energy? is TRUE, the code within brackets will be run...
    ask wolves [ set label round energy ]   ; ... then the wolves will show their energy (round means no decimals)
    ask sheep [ set label round energy ]   ; sheep always have energy when there is grass
  ]
end

to add-humans   ; observer procedure
  ; Create as many humans as the slider
  ask n-of initial-number-humans land-patches [  ; This way of creating humans prevents having to give them coordinates
  sprout-humans 1 [   ; Create humans, then initialize their variables
    set shape "person"   ; humans are "person" shaped
    set size 5   ; a bit bigger than turtles and wolves
    set color house-color   ; humans take the house color of the patch on which they are created
    set energy random (2 * wolf-gain-from-food)   ; the initial energy is up to the gain that wolves get * 2
    ]
  ]

end

to reproduce [ reproduce-rate ]     ; procedure that requires a value (reproduce-rate)

  if random-float 100 < reproduce-rate [     ; throw "dice" to see if you will reproduce
    set energy (energy / 2)     ; divide energy between parent and offspring
    hatch 1 [ rt random-float 360 fd 1 ]     ; hatch an offspring and move it forward 1 step
  ]

end

;;; HUMAN PROCEDURE ;;;

to humans-eat
  ; this is a modified version of the sheep-eat
  ifelse random 100 < rate-sheep-eating [     ; Humans will eat sheep only a certain % of time, based on a slider.
  ; If the random value is below rate-sheep-eating, the human eats a sheep.
    let prey one-of sheep-here     ; grab a random sheep
    if prey != nobody [     ; did we get one?  if so,
      ask prey [ die ]     ; kill it, and...
      set energy energy + wolf-gain-from-food     ; get energy from eating. For simplicity, the same energy as wolves
    ]
  ][      ; If not eating a sheep, still getting some nutrients from cultivated grass (wheat?)
    if pcolor = green [
      set pcolor brown
      set energy energy + (sheep-gain-from-food / 4)    ; But still not as good as eating a sheep
    ]
  ]

end

;;; HUMAN PROCEDURE ;;;

to domesticate-wolves
  ; when a human encounters a wild wolf (on same patch), there is a 50-50 chance they will domesticate it or get eaten
  let friend one-of wolves-here    ; grab a random wolf on the same patch
  if friend != nobody [    ; did we get one?  if so,
  ; 50% of the time, the human will domesticate the wolf if it is wild
    if [ domesticated? ] of friend = false [    ; check the domesticated status. If still wild
      ifelse random 100 < 50 [    ; throw the dice. "random 100" will give values between 0-99 inclusively.
        ask friend [    ; this bracket is if the condition above is true (if the value is < 50)
          set domesticated? true    ; this variable becomes true
          set color 2      ; transform the wolf into a dog (set color to grey)
        ]   ; end of the "if" bracket (if dice roll < 50)
      ][   ; the rest of the time (50% of the time), the wild wolf will kill the human
        ask friend [
          set energy energy + ( wolf-gain-from-food * 1.5 )   ; the wild wolf gets some food out of the human (1.5* sheep's worth)
        ]   ; end of the "else" bracket
        die    ; and the human dies
      ]
    ]
  ]

end

;;; HUMAN PROCEDURE ;;;

to humans-feed-animals
  ; Identifies the dogs and feed them by sharing a sheep if there is one around
  let dogs wolves-here with [ domesticated? = true ]   ; temporary variable to identify dogs on the same patch

  if any? dogs [   ; if there are any dogs here
    ask one-of dogs [
      eat-sheep   ; the human tells its dog to hunt a sheep ...
      set energy energy - 20  ; ... and take some of the nutrients for itself (but not all of it)
    ]   ; end of the "ask one-of dogs"
    set energy energy + 20   ; the human also gets nutrients from the hunted sheep
  ]   ; end of the "if any? dogs" bracket

end


; Copyright 1997 Uri Wilensky.
; See Info tab for full copyright and license.
@#$#@#$#@
GRAPHICS-WINDOW
355
10
684
781
-1
-1
3.0
1
14
1
1
1
0
0
0
1
0
106
0
253
1
1
1
ticks
30.0

SLIDER
5
10
179
43
initial-number-sheep
initial-number-sheep
0
250
100.0
1
1
NIL
HORIZONTAL

SLIDER
5
146
179
179
sheep-gain-from-food
sheep-gain-from-food
0.0
50.0
5.0
1.0
1
NIL
HORIZONTAL

SLIDER
5
181
179
214
sheep-reproduce
sheep-reproduce
1.0
20.0
4.0
1.0
1
%
HORIZONTAL

SLIDER
185
10
350
43
initial-number-wolves
initial-number-wolves
0
250
57.0
1
1
NIL
HORIZONTAL

SLIDER
183
145
348
178
wolf-gain-from-food
wolf-gain-from-food
0.0
100.0
50.0
1.0
1
NIL
HORIZONTAL

SLIDER
183
181
348
214
wolf-reproduce
wolf-reproduce
0.0
20.0
5.0
1.0
1
%
HORIZONTAL

SLIDER
40
50
252
83
grass-regrowth-time
grass-regrowth-time
0
100
31.0
1
1
NIL
HORIZONTAL

BUTTON
40
90
109
123
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
115
90
190
123
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

PLOT
10
310
350
480
populations
time
pop.
0.0
100.0
0.0
100.0
true
true
"" ""
PENS
"sheep" 1.0 0 -612749 true "" "plot count sheep"
"wolves" 1.0 0 -16449023 true "" "plot count wolves with [domesticated? = false]"
"dogs" 1.0 0 -7500403 true "" "plot count wolves with [domesticated? = true]"
"humans" 1.0 0 -13345367 true "" "plot count humans"

MONITOR
41
258
111
303
sheep
count sheep
3
1
11

MONITOR
115
258
185
303
wolves
count wolves
3
1
11

MONITOR
191
258
256
303
grass
count grass / 4
0
1
11

TEXTBOX
20
128
160
146
Sheep settings
11
0.0
0

TEXTBOX
198
126
311
144
Wolf settings
11
0.0
0

SWITCH
105
220
241
253
show-energy?
show-energy?
1
1
-1000

SLIDER
690
10
885
43
initial-number-humans
initial-number-humans
0
100
50.0
5
1
NIL
HORIZONTAL

SLIDER
690
50
885
83
humans-reproduce
humans-reproduce
0
10
2.0
1
1
%
HORIZONTAL

SLIDER
690
90
885
123
rate-sheep-eating
rate-sheep-eating
0
50
50.0
1
1
%
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This modifies the Wolf Sheep Predation model by adding people. The people move around the landscape and can domesticate some of the wolves they encounter (or get eaten by them). People can feed on grass (let's pretend it's wheat) and sheep as well.

In this new step, the model is now set in Westeros. The land is divided into the 7 kingdoms, which are separated from the land of the Wildlings by the wall. People take on the color of the house where they were born.

## WHAT TO TRY?

Now that we added a new component, try to find the variable values that lead to an equilibrium between all species. Is it possible?

## RELATED MODELS

This model is built on a previous modification of the Wolf Sheep Predation model. The references below are for that model.

## CREDITS AND REFERENCES

* Wilensky, U. (1997).  NetLogo Wolf Sheep Predation model.  http://ccl.northwestern.edu/netlogo/models/WolfSheepPredation.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

Please cite the NetLogo software as:

* Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Polygon -16777216 true false 90 90 210 90 240 285 60 285
Circle -6459832 true false 110 5 80
Polygon -6459832 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -6459832 true false 127 79 172 94
Polygon -6459832 true false 195 90 240 150 225 180 165 105
Polygon -6459832 true false 105 90 60 150 75 180 135 105
Polygon -7500403 true true 90 90 120 90 150 120 180 90 210 90 195 210 105 210
Polygon -7500403 true true 105 210 90 270 135 300 150 240 165 300 210 270 195 210
Rectangle -7500403 false true 150 120 150 120
Polygon -7500403 true true 105 90 68 138 83 169 105 144
Polygon -7500403 true true 195 91 230 140 216 168 195 142
Rectangle -16777216 true false 120 75 120 75
Polygon -7500403 true true 120 90 120 90 120 75 150 90 180 75 180 90 180 90 150 135
Polygon -16777216 true false 122 90 195 165 195 195 105 90
Polygon -16777216 true false 180 90 105 165 105 195 195 90
Polygon -16777216 true false 90 90 90 105 120 90
Polygon -16777216 true false 180 90 210 105 210 90

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
set model-version "sheep-wolves-grass"
set show-energy? false
setup
repeat 75 [ go ]
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
1
@#$#@#$#@
